#[repr(u8)]pub enum Ccif {
CCIF0 = 0,
CCIF1 = 1,
}Variants
CCIF0 = 0
Flash command, initialization, or power mode recovery in progress
CCIF1 = 1
Flash command, initialization, or power mode recovery has completed
Implementations